@@ -81,16 +81,16 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -1019,7 +1019,10 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
     ) -> Callable[[cluster_service.SetNodePoolSizeRequest], cluster_service.Operation]:
         r"""Return a callable for the set node pool size method over gRPC.
 
-        Sets the size for a specific node pool.
+        SetNodePoolSizeRequest sets the size of a node pool. The new
+        size will be used for all replicas, including future replicas
+        created by modifying
+        [NodePool.locations][google.container.v1beta1.NodePool.locations].
 
         Returns:
             Callable[[~.SetNodePoolSizeRequest],
