@@ -17,6 +17,7 @@ from .cluster_service import (
     AcceleratorConfig,
     AddonsConfig,
     AuthenticatorGroupsConfig,
+    Autopilot,
     AutoprovisioningNodePoolDefaults,
     AutoUpgradeOptions,
     BinaryAuthorization,
@@ -38,6 +39,7 @@ from .cluster_service import (
     DeleteClusterRequest,
     DeleteNodePoolRequest,
     DnsCacheConfig,
+    DNSConfig,
     EphemeralStorageConfig,
     GcePersistentDiskCsiDriverConfig,
     GetClusterRequest,
@@ -50,6 +52,8 @@ from .cluster_service import (
     GetServerConfigRequest,
     HorizontalPodAutoscaling,
     HttpLoadBalancing,
+    IdentityServiceConfig,
+    ILBSubsettingConfig,
     IntraNodeVisibilityConfig,
     IPAllocationPolicy,
     IstioConfig,
@@ -69,21 +73,31 @@ from .cluster_service import (
     ListUsableSubnetworksRequest,
     ListUsableSubnetworksResponse,
     Location,
+    LoggingComponentConfig,
+    LoggingConfig,
     MaintenancePolicy,
     MaintenanceWindow,
     Master,
     MasterAuth,
     MasterAuthorizedNetworksConfig,
     MaxPodsConstraint,
+    MonitoringComponentConfig,
+    MonitoringConfig,
     NetworkConfig,
     NetworkPolicy,
     NetworkPolicyConfig,
+    NetworkTags,
     NodeConfig,
+    NodeConfigDefaults,
     NodeKubeletConfig,
+    NodeLabels,
     NodeManagement,
+    NodeNetworkConfig,
     NodePool,
     NodePoolAutoscaling,
+    NodePoolDefaults,
     NodeTaint,
+    NodeTaints,
     NotificationConfig,
     Operation,
     OperationProgress,
@@ -98,6 +112,7 @@ from .cluster_service import (
     RollbackNodePoolUpgradeRequest,
     SandboxConfig,
     ServerConfig,
+    ServiceExternalIPsConfig,
     SetAddonsConfigRequest,
     SetLabelsRequest,
     SetLegacyAbacRequest,
@@ -119,13 +134,18 @@ from .cluster_service import (
     UpdateClusterRequest,
     UpdateMasterRequest,
     UpdateNodePoolRequest,
+    UpgradeAvailableEvent,
     UpgradeEvent,
     UsableSubnetwork,
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
+    VirtualNIC,
+    WindowsVersions,
+    WorkloadCertificates,
     WorkloadIdentityConfig,
     WorkloadMetadataConfig,
     DatapathProvider,
+    PrivateIPv6GoogleAccess,
     UpgradeResourceType,
 )
 
@@ -133,6 +153,7 @@ __all__ = (
     "AcceleratorConfig",
     "AddonsConfig",
     "AuthenticatorGroupsConfig",
+    "Autopilot",
     "AutoprovisioningNodePoolDefaults",
     "AutoUpgradeOptions",
     "BinaryAuthorization",
@@ -154,6 +175,7 @@ __all__ = (
     "DeleteClusterRequest",
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
+    "DNSConfig",
     "EphemeralStorageConfig",
     "GcePersistentDiskCsiDriverConfig",
     "GetClusterRequest",
@@ -166,6 +188,8 @@ __all__ = (
     "GetServerConfigRequest",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
+    "IdentityServiceConfig",
+    "ILBSubsettingConfig",
     "IntraNodeVisibilityConfig",
     "IPAllocationPolicy",
     "IstioConfig",
@@ -185,21 +209,31 @@ __all__ = (
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
     "Location",
+    "LoggingComponentConfig",
+    "LoggingConfig",
     "MaintenancePolicy",
     "MaintenanceWindow",
     "Master",
     "MasterAuth",
     "MasterAuthorizedNetworksConfig",
     "MaxPodsConstraint",
+    "MonitoringComponentConfig",
+    "MonitoringConfig",
     "NetworkConfig",
     "NetworkPolicy",
     "NetworkPolicyConfig",
+    "NetworkTags",
     "NodeConfig",
+    "NodeConfigDefaults",
     "NodeKubeletConfig",
+    "NodeLabels",
     "NodeManagement",
+    "NodeNetworkConfig",
     "NodePool",
     "NodePoolAutoscaling",
+    "NodePoolDefaults",
     "NodeTaint",
+    "NodeTaints",
     "NotificationConfig",
     "Operation",
     "OperationProgress",
@@ -214,6 +248,7 @@ __all__ = (
     "RollbackNodePoolUpgradeRequest",
     "SandboxConfig",
     "ServerConfig",
+    "ServiceExternalIPsConfig",
     "SetAddonsConfigRequest",
     "SetLabelsRequest",
     "SetLegacyAbacRequest",
@@ -235,12 +270,17 @@ __all__ = (
     "UpdateClusterRequest",
     "UpdateMasterRequest",
     "UpdateNodePoolRequest",
+    "UpgradeAvailableEvent",
     "UpgradeEvent",
     "UsableSubnetwork",
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
+    "VirtualNIC",
+    "WindowsVersions",
+    "WorkloadCertificates",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
     "DatapathProvider",
+    "PrivateIPv6GoogleAccess",
     "UpgradeResourceType",
 )
